pub struct DbscanConfig {
pub eps: f64,
pub min_samples: usize,
}Expand description
Configuration for DBSCAN clustering
Fields
eps: f64Maximum distance between samples for one to be considered in the neighborhood of the other
min_samples: usizeMinimum number of samples in a neighborhood for a point to be a core point